@@ -41,12 +41,12 @@
  * escape special characters .. needs work
  */
 static int
-roff_fprintf (GsfOutput *output, Cell *cell)
+roff_fprintf (GsfOutput *output, GnmCell *cell)
 {
 	int len, i;
 	const char *p;
 	char * s;
-	MStyle *mstyle;
+	GnmStyle *mstyle;
 
 	if (cell_is_empty (cell))
 		return 0;
@@ -89,7 +89,7 @@ roff_file_save (GnmFileSaver const *fs, IOContext *io_context,
                 WorkbookView const *wb_view, GsfOutput *output)
 {
 	GList *sheets, *ptr;
-	Cell *cell;
+	GnmCell *cell;
 	int row, col, fontsize, v_size;
 	Workbook *wb = wb_view_workbook (wb_view);
 
@@ -123,7 +123,7 @@ roff_file_save (GnmFileSaver const *fs, IOContext *io_context,
 				if (!cell) {
 					gsf_output_printf (output, "l");
 				} else {
-					MStyle *mstyle = cell_get_mstyle (cell);
+					GnmStyle *mstyle = cell_get_mstyle (cell);
 					if (!mstyle)
 						break;
 					if (mstyle_get_align_h (mstyle) & HALIGN_RIGHT)
