@@ -50,6 +50,7 @@
 #include <gsf/gsf-infile-zip.h>
 
 #include <string.h>
+#include <locale.h>
 
 GNUMERIC_MODULE_PLUGIN_INFO_DECL;
 
@@ -59,15 +60,15 @@ typedef struct {
 	IOContext 	*context;	/* The IOcontext managing things */
 	WorkbookView	*wb_view;	/* View for the new workbook */
 
-	ParsePos 	pos;
+	GnmParsePos 	pos;
 
 	int 		 col_inc;
 	gboolean 	 simple_content;
 	gboolean 	 error_content;
 	GHashTable	*styles;
 	GHashTable	*formats;
-	MStyle		*style;
-	MStyle		*col_default_styles[SHEET_MAX_COLS];
+	GnmStyle		*style;
+	GnmStyle		*col_default_styles[SHEET_MAX_COLS];
 	GSList		*sheet_order;
 
 	GnmExprConventions *exprconv;
@@ -129,7 +130,7 @@ oo_attr_int (OOParseState *state, xmlChar const * const *attrs,
 	g_return_val_if_fail (attrs[0] != NULL, FALSE);
 	g_return_val_if_fail (attrs[1] != NULL, FALSE);
 
-	if (strcmp (attrs[0], name))
+	if (!gsf_xml_in_namecmp (&state->base, attrs[0], ns_id, name))
 		return FALSE;
 
 	tmp = strtol ((gchar *)attrs[1], &end, 10);
@@ -166,7 +167,7 @@ oo_attr_float (OOParseState *state, xmlChar const * const *attrs,
 	return TRUE;
 }
 
-static StyleColor *
+static GnmColor *
 oo_attr_color (OOParseState *state, xmlChar const * const *attrs,
 	       int ns_id, char const *name)
 {
@@ -298,7 +299,7 @@ static void
 oo_col_start (GsfXMLIn *xin, xmlChar const **attrs)
 {
 	OOParseState *state = (OOParseState *)xin;
-	MStyle *style = NULL;
+	GnmStyle *style = NULL;
 	int repeat_count = 1;
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
@@ -332,7 +333,7 @@ oo_row_start (GsfXMLIn *xin, xmlChar const **attrs)
 }
 
 static char const *
-oo_cellref_parse (GnmCellRef *ref, char const *start, ParsePos const *pp)
+oo_cellref_parse (GnmCellRef *ref, char const *start, GnmParsePos const *pp)
 {
 	char const *tmp1, *tmp2, *ptr = start;
 	/* sheet name cannot contain '.' */
@@ -377,7 +378,7 @@ oo_cellref_parse (GnmCellRef *ref, char const *start, ParsePos const *pp)
 }
 
 static char const *
-oo_rangeref_parse (GnmRangeRef *ref, char const *start, ParsePos const *pp)
+oo_rangeref_parse (GnmRangeRef *ref, char const *start, GnmParsePos const *pp)
 {
 	char const *ptr;
 
@@ -407,7 +408,7 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 	gnm_float	 float_val;
 	int array_cols = -1, array_rows = -1;
 	int merge_cols = -1, merge_rows = -1;
-	MStyle *style = NULL;
+	GnmStyle *style = NULL;
 
 	state->col_inc = 1;
 	state->error_content = FALSE;
@@ -431,7 +432,7 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 				 */
 				state->error_content = TRUE;
 			else {
-				ParseError  perr;
+				GnmParseError  perr;
 				parse_error_init (&perr);
 				expr = oo_expr_parse_str (expr_string,
 					&state->pos, 0, &perr);
@@ -487,7 +488,7 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 	}
 	state->simple_content = FALSE;
 	if (expr != NULL) {
-		Cell *cell = sheet_cell_fetch (state->pos.sheet,
+		GnmCell *cell = sheet_cell_fetch (state->pos.sheet,
 			state->pos.eval.col, state->pos.eval.row);
 
 		if (array_cols > 0 || array_rows > 0) {
@@ -513,7 +514,7 @@ oo_cell_start (GsfXMLIn *xin, xmlChar const **attrs)
 			gnm_expr_unref (expr);
 		}
 	} else if (val != NULL) {
-		Cell *cell = sheet_cell_fetch (state->pos.sheet,
+		GnmCell *cell = sheet_cell_fetch (state->pos.sheet,
 			state->pos.eval.col, state->pos.eval.row);
 
 		/* has cell previously been initialized as part of an array */
@@ -543,15 +544,16 @@ oo_cell_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 	OOParseState *state = (OOParseState *)xin;
 
 	if (state->col_inc > 1) {
-		Cell *cell = sheet_cell_get (state->pos.sheet, state->pos.eval.col, state->pos.eval.row);
+		GnmCell *cell = sheet_cell_get (state->pos.sheet,
+			state->pos.eval.col, state->pos.eval.row);
 
 		if (!cell_is_empty (cell)) {
 			int i = 1;
-			Cell *next;
+			GnmCell *next;
 			for (; i < state->col_inc ; i++) {
 				next = sheet_cell_fetch (state->pos.sheet,
 					state->pos.eval.col + i, state->pos.eval.row);
-				cell_set_value (next, value_duplicate (cell->value));
+				cell_set_value (next, value_dup (cell->value));
 			}
 		}
 	}
@@ -597,8 +599,9 @@ oo_cell_content_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *blob)
 	OOParseState *state = (OOParseState *)xin;
 
 	if (state->simple_content || state->error_content) {
-		Cell *cell = sheet_cell_fetch (state->pos.sheet, state->pos.eval.col, state->pos.eval.row);
 		GnmValue *v;
+		GnmCell *cell = sheet_cell_fetch (state->pos.sheet,
+			state->pos.eval.col, state->pos.eval.row);
 
 		if (state->simple_content)
 			v = value_new_string (state->base.content->str);
@@ -612,19 +615,19 @@ oo_style (GsfXMLIn *xin, xmlChar const **attrs)
 {
 	OOParseState *state = (OOParseState *)xin;
 	xmlChar const *name = NULL;
-	MStyle *parent = NULL;
-	StyleFormat *fmt = NULL;
+	GnmStyle *parent = NULL;
+	GnmFormat *fmt = NULL;
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
 		/* ignore  style:family the names seem unique enough */
 		if (gsf_xml_in_namecmp (xin, attrs[0], OO_NS_STYLE, "name"))
 			name = attrs[1];
 		else if (gsf_xml_in_namecmp (xin, attrs[0], OO_NS_STYLE, "parent-style-name")) {
-			MStyle *tmp = g_hash_table_lookup (state->styles, attrs[1]);
+			GnmStyle *tmp = g_hash_table_lookup (state->styles, attrs[1]);
 			if (tmp != NULL)
 				parent = tmp;
 		} else if (gsf_xml_in_namecmp (xin, attrs[0], OO_NS_STYLE, "data-style-name")) {
-			StyleFormat *tmp = g_hash_table_lookup (state->formats, attrs[1]);
+			GnmFormat *tmp = g_hash_table_lookup (state->formats, attrs[1]);
 			if (tmp != NULL)
 				fmt = tmp;
 		}
@@ -665,8 +668,8 @@ oo_style_prop (GsfXMLIn *xin, xmlChar const **attrs)
 		{ NULL,	0 },
 	};
 	OOParseState *state = (OOParseState *)xin;
-	StyleColor *color;
-	MStyle *style = state->style;
+	GnmColor *color;
+	GnmStyle *style = state->style;
 	StyleHAlignFlags h_align = HALIGN_GENERAL;
 	gboolean h_align_is_valid = FALSE;
 	int tmp;
@@ -730,8 +733,8 @@ oo_named_expr (GsfXMLIn *xin, xmlChar const **attrs)
 			expr_str = attrs[1];
 
 	if (name != NULL && base_str != NULL && expr_str != NULL) {
-		ParseError perr;
-		ParsePos   pp;
+		GnmParseError perr;
+		GnmParsePos   pp;
 		GnmExpr const *expr;
 		char *tmp = g_strconcat ("[", base_str, "]", NULL);
 
@@ -824,6 +827,10 @@ GSF_XML_IN_NODE (START, OFFICE, OO_NS_OFFICE, "document-content", FALSE, NULL, N
 	GSF_XML_IN_NODE (TABLE_ROW, TABLE_COVERED_CELL, OO_NS_TABLE, "covered-table-cell", FALSE, &oo_covered_cell_start, &oo_covered_cell_end),
 	  GSF_XML_IN_NODE (TABLE_CELL, CELL_TEXT, OO_NS_TEXT, "p", TRUE, NULL, &oo_cell_content_end),
 	    GSF_XML_IN_NODE (CELL_TEXT, CELL_TEXT_S, OO_NS_TEXT, "s", FALSE, NULL, NULL),
+	  GSF_XML_IN_NODE (TABLE_CELL, CELL_OBJECT, OO_NS_DRAW, "object", FALSE, NULL, NULL),		/* ignore for now */
+	  GSF_XML_IN_NODE (TABLE_CELL, CELL_GRAPHIC, OO_NS_DRAW, "g", FALSE, NULL, NULL),		/* ignore for now */
+	    GSF_XML_IN_NODE (CELL_GRAPHIC, CELL_GRAPHIC, OO_NS_DRAW, "g", FALSE, NULL, NULL),		/* 2nd def */
+	    GSF_XML_IN_NODE (CELL_GRAPHIC, DRAW_POLYLINE, OO_NS_DRAW, "polyline", FALSE, NULL, NULL),		/* 2nd def */
       GSF_XML_IN_NODE (TABLE, TABLE_COL_GROUP, OO_NS_TABLE, "table-column-group", FALSE, NULL, NULL),
         GSF_XML_IN_NODE (TABLE_COL_GROUP, TABLE_COL_GROUP, OO_NS_TABLE, "table-column-group", FALSE, NULL, NULL),
         GSF_XML_IN_NODE (TABLE_COL_GROUP, TABLE_COL, OO_NS_TABLE, "table-column", FALSE, NULL, NULL), /* 2nd def */
@@ -832,6 +839,10 @@ GSF_XML_IN_NODE (START, OFFICE, OO_NS_OFFICE, "document-content", FALSE, NULL, N
         GSF_XML_IN_NODE (TABLE_ROW_GROUP, TABLE_ROW,	    OO_NS_TABLE, "table-row", FALSE, NULL, NULL), /* 2nd def */
     GSF_XML_IN_NODE (OFFICE_BODY, NAMED_EXPRS, OO_NS_TABLE, "named-expressions", FALSE, NULL, NULL),
       GSF_XML_IN_NODE (NAMED_EXPRS, NAMED_EXPR, OO_NS_TABLE, "named-expression", FALSE, &oo_named_expr, NULL),
+    GSF_XML_IN_NODE (OFFICE_BODY, DB_RANGES, OO_NS_TABLE, "database-ranges", FALSE, NULL, NULL),
+      GSF_XML_IN_NODE (DB_RANGES, DB_RANGE, OO_NS_TABLE, "database-range", FALSE, NULL, NULL),
+        GSF_XML_IN_NODE (DB_RANGE, TABLE_SORT, OO_NS_TABLE, "sort", FALSE, NULL, NULL),
+          GSF_XML_IN_NODE (TABLE_SORT, SORT_BY, OO_NS_TABLE, "sort-by", FALSE, NULL, NULL),
   { NULL }
 };
 
@@ -912,6 +923,7 @@ void
 openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
 		      WorkbookView *wb_view, GsfInput *input)
 {
+	char *old_num_locale, *old_monetary_locale;
 	OOParseState state;
 	GsfInput *content = NULL;
 	GError   *err = NULL;
@@ -924,7 +936,7 @@ openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	zip = gsf_infile_zip_new (input, &err);
 	if (zip == NULL) {
 		g_return_if_fail (err != NULL);
-		gnumeric_error_read (COMMAND_CONTEXT (io_context),
+		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (io_context),
 			err->message);
 		g_error_free (err);
 		return;
@@ -933,12 +945,18 @@ openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
 	content = gsf_infile_child_by_name (GSF_INFILE (zip),
 					    "content.xml");
 	if (content == NULL) {
-		gnumeric_error_read (COMMAND_CONTEXT (io_context),
+		gnm_cmd_context_error_import (GNM_CMD_CONTEXT (io_context),
 			 _("No stream named content.xml found."));
 		g_object_unref (G_OBJECT (zip));
 		return;
 	}
 
+	old_num_locale = g_strdup (gnm_setlocale (LC_NUMERIC, NULL));
+	gnm_setlocale (LC_NUMERIC, "C");
+	old_monetary_locale = g_strdup (gnm_setlocale (LC_MONETARY, NULL));
+	gnm_setlocale (LC_MONETARY, "C");
+	gnm_set_untranslated_bools ();
+
 	/* init */
 	state.context = io_context;
 	state.wb_view = wb_view;
@@ -985,6 +1003,12 @@ openoffice_file_open (GnmFileOpener const *fo, IOContext *io_context,
 		sheet_flag_recompute_spans (workbook_sheet_by_index (state.pos.wb, i));
 
 	gnm_expr_conventions_free (state.exprconv);
+
+	/* gnm_setlocale restores bools to locale translation */
+	gnm_setlocale (LC_MONETARY, old_monetary_locale);
+	g_free (old_monetary_locale);
+	gnm_setlocale (LC_NUMERIC, old_num_locale);
+	g_free (old_num_locale);
 }
 
 void
